@@ -60,10 +60,23 @@ class websocket_outgoing_message
 public:
 #if !defined(__cplusplus_winrt)
     /// <summary>
-    /// Sets a the outgoing message to be an unsolicited pong message.
+    /// Sets the outgoing message to be a ping message.
     /// This is useful when the client side wants to check whether the server is alive.
     /// </summary>
-    void set_pong_message() { this->set_message_pong(); }
+    /// <param name="data">UTF-8 String containing the optional ping message.</param>
+    void set_ping_message(const std::string& data = {})
+    {
+        this->set_message_ping(concurrency::streams::container_buffer<std::string>(data));
+    }
+
+    /// <summary>
+    /// Sets the outgoing message to be an unsolicited pong message.
+    /// </summary>
+    /// <param name="data">UTF-8 String containing the optional pong message.</param>
+    void set_pong_message(const std::string& data = {})
+    {
+        this->set_message_pong(concurrency::streams::container_buffer<std::string>(data));
+    }
 #endif
 
     /// <summary>
@@ -140,9 +153,14 @@ private:
     const pplx::task_completion_event<void>& body_sent() const { return m_body_sent; }
 
 #if !defined(__cplusplus_winrt)
-    void set_message_pong()
+    void set_message_ping(const concurrency::streams::container_buffer<std::string>& buffer)
+    {
+        m_msg_type = websocket_message_type::ping;
+        m_length = static_cast<size_t>(buffer.size());
+        m_body = buffer;
+    }
+    void set_message_pong(const concurrency::streams::container_buffer<std::string>& buffer)
     {
-        concurrency::streams::container_buffer<std::string> buffer("");
         m_msg_type = websocket_message_type::pong;
         m_length = static_cast<size_t>(buffer.size());
         m_body = buffer;
