@@ -10,10 +10,10 @@
  * =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
  ****/
 
-#include "stdafx.h"
-
+#include "cpprest/json.h"
 #include "cpprest/containerstream.h"
 #include "cpprest/filestream.h"
+#include "unittestpp.h"
 
 using namespace web;
 
